@@ -10,7 +10,7 @@ use base qw(Exporter);
 use strict;
 use vars qw( @EXPORT @EXPORT_OK %BrailleAsciiToUnicode %BrailleUnicodeToAscii $VERSION );
 
-$VERSION = 0.02;
+$VERSION = 0.03;
 
 @EXPORT = qw(
 		brailleDotsToUnicode
@@ -35,71 +35,71 @@ $VERSION = 0.02;
 );
 
 %BrailleAsciiToUnicode =(
-	A	=> chr(0x2801),  # chr creates a valid utf8 sequence
-	B	=> chr(0x2803),
-	C	=> chr(0x2809),
-	D	=> chr(0x2819),
-	E	=> chr(0x2811),
-	F	=> chr(0x280b),
-	G	=> chr(0x281b),
-	H	=> chr(0x2813),
-	I	=> chr(0x280a),
-	J	=> chr(0x281a),
-	K	=> chr(0x2805),
-	L	=> chr(0x2807),
-	M	=> chr(0x280d),
-	N	=> chr(0x281d),
-	O	=> chr(0x2815),
-	P	=> chr(0x280f),
-	Q	=> chr(0x281f),
-	R	=> chr(0x2817),
-	S	=> chr(0x280e),
-	T	=> chr(0x281e),
-	U	=> chr(0x2825),
-	V	=> chr(0x2827),
-	W	=> chr(0x283a),
-	X	=> chr(0x282d),
-	Y	=> chr(0x283d),
-	Z	=> chr(0x2835),
+	A	=> '⠁',
+	B	=> '⠃',
+	C	=> '⠉',
+	D	=> '⠙',
+	E	=> '⠑',
+	F	=> '⠋',
+	G	=> '⠛',
+	H	=> '⠓',
+	I	=> '⠊',
+	J	=> '⠚',
+	K	=> '⠅',
+	L	=> '⠇',
+	M	=> '⠍',
+	N	=> '⠝',
+	O	=> '⠕',
+	P	=> '⠏',
+	Q	=> '⠟',
+	R	=> '⠗',
+	S	=> '⠎',
+	T	=> '⠞',
+	U	=> '⠥',
+	V	=> '⠧',
+	W	=> '⠺',
+	X	=> '⠭',
+	Y	=> '⠽',
+	Z	=> '⠵',
 
-	1	=> chr(0x2802),
-	2	=> chr(0x2806),
-	3	=> chr(0x2812),
-	4	=> chr(0x2832),
-	5	=> chr(0x2822),
-	6	=> chr(0x2816),
-	7	=> chr(0x2836),
-	8	=> chr(0x2826),
-	9	=> chr(0x2814),
-	0	=> chr(0x2834),
+	1	=> '⠂',
+	2	=> '⠆',
+	3	=> '⠒',
+	4	=> '⠲',
+	5	=> '⠢',
+	6	=> '⠖',
+	7	=> '⠶',
+	8	=> '⠦',
+	9	=> '⠔',
+	0	=> '⠴',
 
-	','	=> chr(0x2804),
-	'@'	=> chr(0x2808),
-	'/'	=> chr(0x280c),
-	'"'	=> chr(0x2810),
-	'^'	=> chr(0x2818),
-	'>'	=> chr(0x281c),
-	'\''=> chr(0x2820),
-	'*'	=> chr(0x2821),
-	'<'	=> chr(0x2823),
-	'-'	=> chr(0x2824),
-	'.'	=> chr(0x2828),
-	'%'	=> chr(0x2829),
-	'['	=> chr(0x282a),
-	'$'	=> chr(0x282b),
-	'+'	=> chr(0x282c),
-	'!'	=> chr(0x282e),
-	'&'	=> chr(0x282f),
-	';'	=> chr(0x2830),
-	':'	=> chr(0x2831),
-	'\\'=> chr(0x2833),
-	'('	=> chr(0x2837),
-	'_'	=> chr(0x2838),
-	'?'	=> chr(0x2839),
-	']'	=> chr(0x283b),
-	'#'	=> chr(0x283c),
-	')'	=> chr(0x283e),
-	'='	=> chr(0x283f)
+	','	=> '⠄',
+	'@'	=> '⠈',
+	'/'	=> '⠌',
+	'"'	=> '⠐',
+	'^'	=> '⠘',
+	'>'	=> '⠜',
+	'\''=> '⠠',
+	'*'	=> '⠡',
+	'<'	=> '⠣',
+	'-'	=> '⠤',
+	'.'	=> '⠨',
+	'%'	=> '⠩',
+	'['	=> '⠪',
+	'$'	=> '⠫',
+	'+'	=> '⠬',
+	'!'	=> '⠮',
+	'&'	=> '⠯',
+	';'	=> '⠰',
+	':'	=> '⠱',
+	'\\'=> '⠳',
+	'('	=> '⠷',
+	'_'	=> '⠸',
+	'?'	=> '⠹',
+	']'	=> '⠻',
+	'#'	=> '⠼',
+	')'	=> '⠾',
+	'='	=> '⠿'
 );
 
 
